You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [30/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscardUnreachable.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscardUnreachable.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscardUnreachable.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscardUnreachable.java Wed Jan  2 05:20:52 2013
@@ -60,14 +60,14 @@ public class DiscardUnreachable extends 
      * <p><ul>
      *    <li> re-configures the lookup locator discovery utility to discover
      *         the set of locators whose elements are the locators of each
-     *         lookup service that was started during setup
+     *         lookup service that was started during construct
      *    <li> starts the unicast discovery process by adding to the
      *         lookup locator discovery utility, a listener that listens
      *         for only discovered and discarded events
      *    <li> verifies that the discovery process is working by waiting
      *         for the expected discovery events
      *    <li> retrieves the proxy to each lookup service 
-     *    <li> renders un-reachable, each lookup service started in setup
+     *    <li> renders un-reachable, each lookup service started in construct
      *    <li> discards from the lookup locator discovery utility, each
      *         un-reachable lookup service
      *    <li> verifies that the lookup locator discovery utility under test
@@ -87,7 +87,7 @@ public class DiscardUnreachable extends 
          */
         synchronized(mainListener) {
             logger.log(Level.FINE, "terminating each lookup service ...");
-            /* Stop announcements & destroy all lookups started in setup */
+            /* Stop announcements & destroy all lookups started in construct */
             terminateAllLookups();
             DiscoveryServiceUtil.delayMS(7000);//wait for shutdown complete
             logger.log(Level.FINE, "discarding un-reachable lookup services ...");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/Discovered.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/Discovered.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/Discovered.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/Discovered.java Wed Jan  2 05:20:52 2013
@@ -31,7 +31,7 @@ import com.sun.jini.qa.harness.TestExcep
  *
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more "initial" lookup services, each started during setup,
+ *   <li> one or more "initial" lookup services, each started during construct,
  *        before the test begins execution
  *   <li> one client with one instance of the lookup locator discovery utility
  *   <li> the lookup locator discovery utility is configured to discover the
@@ -52,7 +52,7 @@ public class Discovered extends Abstract
      * <p><ul>
      *    <li> configures the lookup locator discovery utility to discover
      *         the set of locators whose elements are the locators of each
-     *         lookup service that was started during setup
+     *         lookup service that was started during construct
      *    <li> starts the unicast discovery process by adding a discovery
      *         listener to the lookup locator discovery utility
      *    <li> verifies that the lookup locator discovery utility under test
@@ -62,7 +62,7 @@ public class Discovered extends Abstract
      */
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");
-        doDiscovery(initLookupsToStart,mainListener);
+        doDiscovery(getInitLookupsToStart(),mainListener);
     }//end run
 
 }//end class Discovered

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveredDelay.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveredDelay.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveredDelay.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveredDelay.java Wed Jan  2 05:20:52 2013
@@ -38,11 +38,11 @@ import java.util.Iterator;
  *
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more "initial" lookup services, each started during setup,
+ *   <li> one or more "initial" lookup services, each started during construct,
  *        before the test begins execution
  *   <li> one or more "additional" lookup services, each started after the
  *        test has begun execution, and after the initial lookup services
- *        started during setup have been discovered
+ *        started during construct have been discovered
  *   <li> one instance of the lookup locator discovery utility
  *   <li> the lookup locator discovery utility is configured to discover the
  *        set of locators whose elements are the locators of each lookup
@@ -62,7 +62,7 @@ public class DiscoveredDelay extends Dis
      * <p><ul>
      *    <li> configures the lookup locator discovery utility to discover
      *         the set of locators whose elements are the locators of each
-     *         lookup service that was started during setup
+     *         lookup service that was started during construct
      *    <li> starts the unicast discovery process by adding a discovery
      *         listener to the lookup locator discovery utility
      *    <li> verifies that the lookup locator discovery utility under test
@@ -81,11 +81,11 @@ public class DiscoveredDelay extends Dis
         super.run();
 
         /* Configure the listener's expected lookups for all the lookups */
-        mainListener.setLookupsToDiscover(allLookupsToStart);
+        mainListener.setLookupsToDiscover(getAllLookupsToStart());
         /* Configure the lookup locator discovery utility to discover both
          * the initial and the additional lookups
          */
-        LookupLocator[] addLocs = toLocatorArray(addLookupsToStart);
+        LookupLocator[] addLocs = toLocatorArray(getAddLookupsToStart());
         locatorDiscovery.addLocators(addLocs);
         logger.log(Level.FINE, "added additional locators to "
                           +"lookup locator discovery --");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveredStagger.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveredStagger.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveredStagger.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveredStagger.java Wed Jan  2 05:20:52 2013
@@ -19,7 +19,7 @@
 package com.sun.jini.test.spec.locatordiscovery;
 
 import java.util.logging.Level;
-
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 import net.jini.core.discovery.LookupLocator;
@@ -55,10 +55,11 @@ public class DiscoveredStagger extends A
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -86,25 +87,25 @@ public class DiscoveredStagger extends A
         boolean oldUseFastTimeout = useFastTimeout;
         useFastTimeout = false;
         StaggeredStartThread lookupsThread =
-                                new StaggeredStartThread(1,allLookupsToStart);
+                                new StaggeredStartThread(1, getAllLookupsToStart());
         try {
             /* Start 1st lookup service (so it's up before discovery starts) */
             LocatorGroupsPair pair
-                                 = (LocatorGroupsPair)allLookupsToStart.get(0);
-	    LookupLocator l = pair.locator;
+                                 = (LocatorGroupsPair)getAllLookupsToStart().get(0);
+	    LookupLocator l = pair.getLocator();
             int port = l.getPort();
             if(portInUse(port)) port = 0;//use randomly chosen port
             startLookup(0, port, l.getHost());
             /* Re-configure LookupLocatorDiscovery to discover given locators*/
             logger.log(Level.FINE, "change LookupLocatorDiscovery to discover -- ");
             LookupLocator[] locatorsToDiscover
-                                          = toLocatorArray(allLookupsToStart);
+                                          = toLocatorArray(getAllLookupsToStart());
             for(int i=0;i<locatorsToDiscover.length;i++) {
                 logger.log(Level.FINE, "    "+locatorsToDiscover[i]);
             }//end loop
             locatorDiscovery.setLocators(locatorsToDiscover);
             /* Add the given listener to the LookupLocatorDiscovery utility */
-            mainListener.setLookupsToDiscover(allLookupsToStart);
+            mainListener.setLookupsToDiscover(getAllLookupsToStart());
             locatorDiscovery.addDiscoveryListener(mainListener);
             /* Start remaining lookup services in a time-staggered fashion */
             lookupsThread.start();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnAddLocsAfterEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnAddLocsAfterEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnAddLocsAfterNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnAddLocsAfterNull.java Wed Jan  2 05:20:52 2013
@@ -36,7 +36,7 @@ import net.jini.core.discovery.LookupLoc
  * <p>
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more initial lookup services started during setup
+ *   <li> one or more initial lookup services started during construct
  *   <li> an instance of the lookup locator discovery utility created by
  *        passing null to the constructor
  *   <li> one instance of DiscoveryListener registered with the lookup
@@ -46,7 +46,7 @@ import net.jini.core.discovery.LookupLoc
  * If the lookup locator discovery utility functions as specified, then the
  * listener will receive no events until the <code>addLocators</code> method
  * is called to re-configure the lookup locator discovery utility to discover
- * the lookup services started during setup.
+ * the lookup services started during construct.
  *
  */
 public class DiscoveryBeginsOnAddLocsAfterNull extends AbstractBaseTest {
@@ -65,10 +65,10 @@ public class DiscoveryBeginsOnAddLocsAft
      *    <li> depending on the value of <code>addLocs</code>, invokes either
      *         addLocators or setLocators to re-configure the lookup locator
      *         discovery utility to discover the lookup services started in
-     *         setup
+     *         construct
      *    <li> verifies that the locator discovery utility utility under test
      *         sends the expected discovered events, having the expected
-     *         contents related to the lookups started in setup
+     *         contents related to the lookups started in construct
      * </ul>
      */
     public void run() throws Exception {
@@ -93,18 +93,18 @@ public class DiscoveryBeginsOnAddLocsAft
         lld.addDiscoveryListener(mainListener);
         waitForDiscovery(mainListener);
         /* Re-configure the listener to expect events for the lookups
-         * started during setup.
+         * started during construct.
          */
-        locsToDiscover = toLocatorArray(initLookupsToStart);
+        locsToDiscover = toLocatorArray(getInitLookupsToStart());
         logger.log(Level.FINE, "calling "+methodStr
                           +" to change the locators to discover to -- ");
         for(int i=0;i<locsToDiscover.length;i++) {
             logger.log(Level.FINE, "   "+locsToDiscover[i]);
         }//end loop
-        mainListener.setLookupsToDiscover(initLookupsToStart);
+        mainListener.setLookupsToDiscover(getInitLookupsToStart());
         /* Using either addLocators ore setLocators, re-configure the 
          * lookup locator discovery utility to discover the lookup
-         * services started in setup
+         * services started in construct
          */
         if(addLocs) {
             lld.addLocators(locsToDiscover);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnSetLocsAfterEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnSetLocsAfterEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryEndsOnTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryEndsOnTerminate.java Wed Jan  2 05:20:52 2013
@@ -36,7 +36,7 @@ import net.jini.core.discovery.LookupLoc
  * <p>
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more initial lookup services started during setup
+ *   <li> one or more initial lookup services started during construct
  *   <li> one or more additional lookup services to be started after
  *        termination of the lookup locator discovery utility
  *   <li> an instance of the lookup locator discovery utility configured to
@@ -82,7 +82,7 @@ public class DiscoveryEndsOnTerminate ex
          * lookup services to be started.
          */
         LookupLocator[] locsToDiscover
-                                    = toLocatorArray(allLookupsToStart);
+                                    = toLocatorArray(getAllLookupsToStart());
         logger.log(Level.FINE, "starting discovery by creating a "
                           +"LookupLocatorDiscovery to discover -- ");
         for(int i=0;i<locsToDiscover.length;i++) {
@@ -96,7 +96,7 @@ public class DiscoveryEndsOnTerminate ex
          * above is operational by verifying that the INITIIAL lookups
          * are discovered.
          */
-        mainListener.setLookupsToDiscover(initLookupsToStart);
+        mainListener.setLookupsToDiscover(getInitLookupsToStart());
         lld.addDiscoveryListener(mainListener);
         waitForDiscovery(mainListener);
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/Equality.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/Equality.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/Equality.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/Equality.java Wed Jan  2 05:20:52 2013
@@ -42,7 +42,7 @@ public class Equality extends AbstractBa
     /** Executes the current test by doing the following:
      * <p>
      *   Compares the instance of <code>LookupLocatorDiscovery</code>
-     *   created during setup to itself and to a new instance; and
+     *   created during construct to itself and to a new instance; and
      *   verifies that the <code>equals</code> method returns the 
      *   appropriate result depending on the particular instances of 
      *   <code>LookupLocatorDiscovery</code> being compared.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetLocators.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetLocators.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetLocators.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetLocators.java Wed Jan  2 05:20:52 2013
@@ -23,7 +23,7 @@ import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.LocatorsUtil;
-
+import com.sun.jini.qa.harness.Test;
 import net.jini.discovery.LookupLocatorDiscovery;
 
 import net.jini.core.discovery.LookupLocator;
@@ -58,13 +58,14 @@ public class GetLocators extends Abstrac
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;//don't start lookups, just want config info
-        super.setup(sysConfig);
-        configLocs = toLocatorArray(initLookupsToStart);
+        super.construct(sysConfig);
+        configLocs = toLocatorArray(getInitLookupsToStart());
         lld = new LookupLocatorDiscovery(configLocs, sysConfig.getConfiguration());
         locatorDiscoveryList.add(lld);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetRegistrars.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetRegistrars.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetRegistrars.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetRegistrars.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import net.jini.core.discovery.LookupLoc
 import net.jini.core.lookup.ServiceRegistrar;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * This class verifies that the <code>LookupLocatorDiscovery</code> utility
@@ -38,11 +39,11 @@ import java.util.ArrayList;
  *
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *    <li> one or more lookup services, each started during setup
+ *    <li> one or more lookup services, each started during construct
  *    <li> one instance of the lookup locator discovery utility
  *    <li> the lookup locator discovery utility is configured to discover the
  *         set of locators whose elements are the locators of each lookup
- *         service that was started in setup
+ *         service that was started in construct
  *    <li> one instance of DiscoveryListener registered with the lookup
  *         locator discovery utility
  * </ul><p>
@@ -59,16 +60,16 @@ public class GetRegistrars extends Disco
      * <p><ul>
      *    <li> configures the lookup locator discovery utility to discover
      *         the set of locators whose elements are the locators of each
-     *         lookup service that was started during setup
+     *         lookup service that was started during construct
      *    <li> starts the unicast discovery process by adding a discovery
      *         listener to the lookup locator discovery utility
      *    <li> verifies that the lookup locator discovery utility under test
      *         discoveres all of the lookup services that were started
-     *         during setup
+     *         during construct
      *    <li> invokes getRegistrars to retrieve the registrars the lookup
      *         locator discovery utility has currently discovered
      *    <li> compares the registrars returned by getRegistrars with the 
-     *         registrars that were started during setup (and discovered
+     *         registrars that were started during construct (and discovered
      *         by the lookup locator discovery utility), and verifies
      *         that those sets are the same
      * </ul>
@@ -79,7 +80,7 @@ public class GetRegistrars extends Disco
 
         logger.log(Level.FINE, "calling getRegistrars ... ");
         ServiceRegistrar[] regs = locatorDiscovery.getRegistrars();
-        ArrayList lusList = getLookupListSnapshot("GetRegistrars.run");
+        List lusList = getLookupListSnapshot("GetRegistrars.run");
         logger.log(Level.FINE, "# of lookups started = "+lusList.size()
                           +", # of registrars from LookupLocatorDiscover = "
                           +regs.length);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetRegistrarsNew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetRegistrarsNew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetRegistrarsNew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetRegistrarsNew.java Wed Jan  2 05:20:52 2013
@@ -34,11 +34,11 @@ import net.jini.core.lookup.ServiceRegis
  *
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *    <li> one or more lookup services, each started during setup
+ *    <li> one or more lookup services, each started during construct
  *    <li> one instance of the lookup locator discovery utility
  *    <li> the lookup locator discovery utility is configured to discover the
  *         set of locators whose elements are the locators of each lookup
- *         service that was started in setup
+ *         service that was started in construct
  *    <li> one instance of DiscoveryListener registered with the lookup
  *         locator discovery utility
  * </ul><p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetUndiscoveredLocators.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetUndiscoveredLocators.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetUndiscoveredLocators.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/GetUndiscoveredLocators.java Wed Jan  2 05:20:52 2013
@@ -37,7 +37,7 @@ import net.jini.core.discovery.LookupLoc
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more initial lookup services with explicitly configured
- *         port numbers that are actually started during setup
+ *         port numbers that are actually started during construct
  *    <li> one or more addtional lookup services with explicitly configured
  *         port numbers that are never actually started during the test
  *    <li> one client with one instance of the lookup locator discovery utility
@@ -60,7 +60,7 @@ public class GetUndiscoveredLocators ext
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> configures the lookup locator discovery utility to discover
-     *         only the initial lookup services started during setup, and
+     *         only the initial lookup services started during construct, and
      *         verifies that the listener is notified of the discovery of
      *         those lookup services (this establishes the set of
      *         already-discovered locators in the listener)
@@ -88,9 +88,9 @@ public class GetUndiscoveredLocators ext
          * lookups so it will have a set of discovered locators and a set
          * of un-discovered locators.
          */
-        locatorDiscovery.setLocators(toLocatorArray(allLookupsToStart));
+        locatorDiscovery.setLocators(toLocatorArray(getAllLookupsToStart()));
         /* Establish the full set of locators expected to be discovered */
-        mainListener.setLookupsToDiscover(allLookupsToStart);
+        mainListener.setLookupsToDiscover(getAllLookupsToStart());
 
         logger.log(Level.FINE, "retrieving un-discovered locators "
                           +"from LookupLocatorDiscovery ...");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveDiscoveryListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveDiscoveryListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveDiscoveryListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveDiscoveryListener.java Wed Jan  2 05:20:52 2013
@@ -38,7 +38,7 @@ import net.jini.core.discovery.LookupLoc
  * <p>
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more initial lookup services started during setup
+ *   <li> one or more initial lookup services started during construct
  *   <li> one or more additional lookup services to be started after
  *        the listener has been removed
  *   <li> an instance of the lookup locator discovery utility configured to
@@ -87,9 +87,9 @@ public class RemoveDiscoveryListener ext
          * lookup services to be started.
          */
         LookupLocator[] locsToDiscover
-                                    = toLocatorArray(allLookupsToStart);
-        LookupLocator[] initLocs = toLocatorArray(initLookupsToStart);
-        LookupLocator[] addLocs = toLocatorArray(addLookupsToStart);
+                                    = toLocatorArray(getAllLookupsToStart());
+        LookupLocator[] initLocs = toLocatorArray(getInitLookupsToStart());
+        LookupLocator[] addLocs = toLocatorArray(getAddLookupsToStart());
         logger.log(Level.FINE, "create LookupLocatorDiscovery to initially "
                           +"discover -- ");
         for(int i=0;i<initLocs.length;i++) {
@@ -111,12 +111,12 @@ public class RemoveDiscoveryListener ext
          * are discovered by both listeners.
          */
         logger.log(Level.FINE, "verifying discovery for initial listener ...");
-        mainListener.setLookupsToDiscover(initLookupsToStart);
+        mainListener.setLookupsToDiscover(getInitLookupsToStart());
         lld.addDiscoveryListener(mainListener);
         waitForDiscovery(mainListener);
 
         logger.log(Level.FINE, "verifying discovery for listener to be removed ...");
-        newListener.setLookupsToDiscover(initLookupsToStart);
+        newListener.setLookupsToDiscover(getInitLookupsToStart());
         lld.addDiscoveryListener(newListener);
         waitForDiscovery(newListener);
 
@@ -150,7 +150,7 @@ public class RemoveDiscoveryListener ext
         logger.log(Level.FINE, "starting additional lookup services ...");
         startAddLookups();
         logger.log(Level.FINE, "verifying events are still being sent ...");
-        mainListener.setLookupsToDiscover(addLookupsToStart);
+        mainListener.setLookupsToDiscover(getAddLookupsToStart());
         waitForDiscovery(mainListener);
 
         logger.log(Level.FINE, "verifying removed listener "

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveDiscoveryListenerDNE.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveDiscoveryListenerDNE.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveDiscoveryListenerDNE.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveDiscoveryListenerDNE.java Wed Jan  2 05:20:52 2013
@@ -61,7 +61,7 @@ public class RemoveDiscoveryListenerDNE 
      *   <ul>
      *     <li> re-configures the lookup locator discovery utility to discover
      *          the set of locators whose elements are the locators of each
-     *          lookup service that was started during setup
+     *          lookup service that was started during construct
      *     <li> starts the unicast discovery process by adding a listener to
      *          the lookup locator discovery utility
      *     <li> verifies that the discovery process is working by waiting

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsAll.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>removeLocators</code> method, this class
@@ -78,10 +79,11 @@ public class RemoveLocatorsAll extends R
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         changeAll = true;
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
 }//end class RemoveLocatorsAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsDups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsDups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsDups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsDups.java Wed Jan  2 05:20:52 2013
@@ -19,7 +19,7 @@
 package com.sun.jini.test.spec.locatordiscovery;
 
 import java.util.logging.Level;
-
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 import net.jini.core.discovery.LookupLocator;
@@ -58,8 +58,8 @@ public class RemoveLocatorsDups extends 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Create a set of locators to remove that contain duplicates */
         dupLocs = new LookupLocator[2*locsToRemove.length];
         int len1 = locsToRemove.length;
@@ -71,7 +71,8 @@ public class RemoveLocatorsDups extends 
             dupLocs[i] = locsToRemove[i-len1];
         }//end loop
         locsToRemove = dupLocs;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class RemoveLocatorsDups
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsEmpty.java Wed Jan  2 05:20:52 2013
@@ -58,7 +58,7 @@ public class RemoveLocatorsEmpty extends
     /** Executes the current test by doing the following:
      * <p><ul>
      *     <li> verifies that the lookup locator discovery utility under test
-     *          discovers the lookup services that were started during setup
+     *          discovers the lookup services that were started during construct
      *     <li> re-configures the listener's expected event state to expect
      *          no more discarded events
      *     <li> removes the empty set from the set of locators with which the
@@ -74,7 +74,7 @@ public class RemoveLocatorsEmpty extends
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");
         /* Verify discovery of the initial lookups */
-        doDiscovery(initLookupsToStart,mainListener);
+        doDiscovery(getInitLookupsToStart(),mainListener);
         mainListener.clearAllEventInfo();
         /* Remove the empty set */
         LookupLocator[] locsToRemove = new LookupLocator[0];

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsNull.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupLocatorDiscovery</code>
@@ -48,10 +49,11 @@ public class RemoveLocatorsNull extends 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         nullLocs = null;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class RemoveLocatorsNull
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsEmpty.java Wed Jan  2 05:20:52 2013
@@ -37,7 +37,7 @@ import net.jini.core.discovery.LookupLoc
  *
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more initial lookup services started during setup
+ *   <li> one or more initial lookup services started during construct
  *   <li> one or more additional lookup services to be started after
  *        setLocators is invoked with the empty set
  *   <li> an instance of the lookup locator discovery utility configured to
@@ -84,7 +84,7 @@ public class SetLocatorsEmpty extends Ab
          * lookup services to be started.
          */
         LookupLocator[] locsToDiscover
-                                    = toLocatorArray(allLookupsToStart);
+                                    = toLocatorArray(getAllLookupsToStart());
         logger.log(Level.FINE, "starting discovery by creating a "
                           +"LookupLocatorDiscovery to discover -- ");
         for(int i=0;i<locsToDiscover.length;i++) {
@@ -99,7 +99,7 @@ public class SetLocatorsEmpty extends Ab
          * above is operational by verifying that the INITIIAL lookups
          * are discovered.
          */
-        mainListener.setLookupsToDiscover(initLookupsToStart);
+        mainListener.setLookupsToDiscover(getInitLookupsToStart());
         lld.addDiscoveryListener(mainListener);
         waitForDiscovery(mainListener);
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsNull.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.locatordi
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupLocatorDiscovery</code>
@@ -48,10 +49,11 @@ public class SetLocatorsNull extends Set
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         nullLocs = null;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class SetLocatorsNull
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.locatordiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>setLocators</code> method, this class verifies
@@ -54,10 +55,11 @@ public class SetLocatorsReplaceAll exten
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         changeAll = true;
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
 }//end class SetLocatorsReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsReplaceSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsReplaceSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsAllGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsAllGroups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -56,13 +57,14 @@ public class AddGroupsAllGroups extends 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;//don't start lookups, just want config info
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	newLD = new LookupDiscovery(groupsToDiscover,
 				    sysConfig.getConfiguration());
 	lookupDiscoveryList.add(newLD);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsDups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsDups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsNullElement.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsNullElement.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -64,9 +65,9 @@ public class AddGroupsNullElement extend
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
-	configGroups = toGroupsArray(initLookupsToStart);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
+	configGroups = toGroupsArray(getInitLookupsToStart());
 	logger.log(Level.FINE, "creating a new "
 		   +"LookupDiscovery initially configured to "
 		   +"discover -- ");
@@ -75,7 +76,8 @@ public class AddGroupsNullElement extend
 	newLD = new LookupDiscovery(configGroups,
 				    sysConfig.getConfiguration());
 	lookupDiscoveryList.add(newLD);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsUnsupportedOperation.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsUnsupportedOperation.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsUnsupportedOperation.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsUnsupportedOperation.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -58,10 +59,11 @@ public class AddGroupsUnsupportedOperati
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;//don't start lookups, just want config info
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddNewDiscoveryChangeListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddNewDiscoveryChangeListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddNewDiscoveryChangeListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddNewDiscoveryChangeListener.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -54,10 +55,11 @@ public class AddNewDiscoveryChangeListen
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         newListener = new AbstractBaseTest.GroupChangeListener();
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class AddNewDiscoveryChangeListener
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddNewDiscoveryListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddNewDiscoveryListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddNewDiscoveryListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddNewDiscoveryListener.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -58,16 +59,17 @@ public class AddNewDiscoveryListener ext
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         newListener = new AbstractBaseTest.LookupListener();
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> re-configures the lookup discovery utility to use group
      *         discovery to discover the set of lookup services started during
-     *         setup
+     *         construct
      *    <li> starts the multicast discovery process by adding a listener to
      *         the lookup discovery utility
      *    <li> verifies that the discovery process is working by waiting
@@ -83,7 +85,7 @@ public class AddNewDiscoveryListener ext
         super.run();
         logger.log(Level.FINE, "adding a new listener to "
                                         +"LookupDiscovery ... ");
-        newListener.setLookupsToDiscover(initLookupsToStart);
+        newListener.setLookupsToDiscover(getInitLookupsToStart());
         lookupDiscovery.addDiscoveryListener(newListener);
         waitForDiscovery(newListener);
     }//end run

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorAllGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorAllGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorAllGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorAllGroups.java Wed Jan  2 05:20:52 2013
@@ -36,7 +36,7 @@ import net.jini.discovery.LookupDiscover
  *
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more initial lookup services started during setup
+ *   <li> one or more initial lookup services started during construct
  *   <li> an instance of the lookup discovery utility constructed with
  *        a null parameter
  *   <li> one instance of DiscoveryListener registered with the lookup
@@ -70,7 +70,7 @@ public class ConstructorAllGroups extend
 				     getConfig().getConfiguration());
         lookupDiscoveryList.add(newLD);
         /* Verify discovery - set the expected groups to discover */
-        mainListener.setLookupsToDiscover(allLookupsToStart);
+        mainListener.setLookupsToDiscover(getAllLookupsToStart());
         /* Add the listener to the LookupDiscovery utility */
         newLD.addDiscoveryListener(mainListener);
         /* Wait for the discovery of the expected lookup service(s) */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorDups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorDups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorNullElement.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorNullElement.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -57,10 +58,11 @@ public class ConstructorNullElement exte
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;//don't start lookups, just want config info
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscardUnreachable.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscardUnreachable.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscardUnreachable.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscardUnreachable.java Wed Jan  2 05:20:52 2013
@@ -92,7 +92,7 @@ public class DiscardUnreachable extends 
         synchronized(mainListener) {
             logger.log(Level.FINE,
                               "terminating each lookup service ...");
-            /* Stop announcements & destroy all lookups started in setup */
+            /* Stop announcements & destroy all lookups started in construct */
             terminateAllLookups();
             DiscoveryServiceUtil.delayMS(7000);//wait for shutdown complete
             logger.log(Level.FINE,

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/Discovered.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/Discovered.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/Discovered.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/Discovered.java Wed Jan  2 05:20:52 2013
@@ -18,13 +18,15 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
+import java.util.ArrayList;
 
 import java.util.logging.Level;
 
 import net.jini.discovery.DiscoveryGroupManagement;
 import net.jini.discovery.LookupDiscovery;
 
-import java.util.ArrayList;
+import java.util.List;
 
 /**
  * This class verifies that the <code>LookupDiscovery</code> utility
@@ -55,28 +57,29 @@ import java.util.ArrayList;
  */
 public class Discovered extends AbstractBaseTest {
 
-    protected ArrayList       locGroupsList  = new ArrayList(1);
-    protected LookupDiscovery ldToUse        = null;
-    protected LookupListener  listenerToUse  = null;
-    protected String[] groupsToDiscover  = DiscoveryGroupManagement.NO_GROUPS;
+    protected volatile List       locGroupsList  = new ArrayList(0);
+    protected volatile LookupDiscovery ldToUse        = null;
+    protected volatile LookupListener  listenerToUse  = null;
+    protected volatile String[] groupsToDiscover  = DiscoveryGroupManagement.NO_GROUPS;
 
     /** Performs actions necessary to prepare for execution of the 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
-	locGroupsList    = initLookupsToStart;
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
+	locGroupsList    = getInitLookupsToStart();
 	ldToUse          = lookupDiscovery;
 	listenerToUse    = mainListener;
 	groupsToDiscover = toGroupsArray(locGroupsList);
+        return this;
     }
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> re-configures the lookup discovery utility to use group
      *         discovery to discover the set of lookup services started during
-     *         setup
+     *         construct
      *    <li> starts the multicast discovery process by adding a listener to
      *         the lookup discovery utility
      *    <li> verifies that the lookup discovery utility under test
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnAddLocsAfterEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnAddLocsAfterEmpty.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.locatordiscovery;
 
+import com.sun.jini.qa.harness.Test;
 import net.jini.core.discovery.LookupLocator;
 import com.sun.jini.qa.harness.QAConfig;
 
@@ -30,7 +31,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * <p>
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more initial lookup services started during setup
  *   <li> an instance of the lookup locator discovery utility created by
  *        passing the empty set to the constructor
  *   <li> one instance of DiscoveryListener registered with the lookup
@@ -40,7 +41,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * If the lookup locator discovery utility functions as specified, then the
  * listener will receive no events until the <code>addLocators</code> method
  * is called to re-configure the lookup locator discovery utility to discover
  * the lookup services started during setup.
  */
 public class DiscoveryBeginsOnAddLocsAfterEmpty
                                   extends DiscoveryBeginsOnAddLocsAfterNull
@@ -50,10 +51,11 @@ public class DiscoveryBeginsOnAddLocsAft
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         locsToDiscover = new LookupLocator[0];
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class DiscoveryBeginsOnAddLocsAfterEmpty
 
@@ -30,7 +31,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more initial lookup services started during setup
+ *   <li> one or more initial lookup services started during construct
  *   <li> an instance of the lookup locator discovery utility created by
  *        passing the empty set to the constructor
@@ -40,7 +41,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * listener will receive no events until the <code>addLocators</code> method
  * is called to re-configure the lookup locator discovery utility to discover
- * the lookup services started during setup.
+ * the lookup services started during construct.
  */
 public class DiscoveryBeginsOnAddLocsAfterEmpty

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnAddLocsAfterNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnAddLocsAfterNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnSetLocsAfterEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnSetLocsAfterEmpty.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.locatordi
 
 import net.jini.core.discovery.LookupLocator;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupLocatorDiscovery</code> utility
@@ -30,7 +31,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * <p>
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more initial lookup services started during setup
  *    <li> an instance of the lookup locator discovery utility created by
  *         passing the empty set to the constructor
  *    <li> one instance of DiscoveryListener registered with the lookup
@@ -40,7 +41,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * If the lookup locator discovery utility functions as specified, then the
  * listener will receive no events until the <code>setLocators</code> method
  * is called to re-configure the lookup locator discovery utility to discover
  * the lookup services started during setup.
  */
 public class DiscoveryBeginsOnSetLocsAfterEmpty
                                   extends DiscoveryBeginsOnSetLocsAfterNull
@@ -50,10 +51,11 @@ public class DiscoveryBeginsOnSetLocsAft
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         locsToDiscover = new LookupLocator[0];
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class DiscoveryBeginsOnSetLocsAfterEmpty
 
@@ -30,7 +31,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *    <li> one or more initial lookup services started during setup
+ *    <li> one or more initial lookup services started during construct
  *    <li> an instance of the lookup locator discovery utility created by
  *         passing the empty set to the constructor
@@ -40,7 +41,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * listener will receive no events until the <code>setLocators</code> method
  * is called to re-configure the lookup locator discovery utility to discover
- * the lookup services started during setup.
+ * the lookup services started during construct.
  */
 public class DiscoveryBeginsOnSetLocsAfterEmpty

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnSetLocsAfterNull.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnSetLocsAfterNull.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnSetLocsAfterNull.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryBeginsOnSetLocsAfterNull.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.locatordiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupLocatorDiscovery</code> utility
@@ -28,7 +29,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * <p>
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more initial lookup services started during setup
  *    <li> an instance of the lookup locator discovery utility created by
  *         passing null to the constructor
  *    <li> one instance of DiscoveryListener registered with the lookup
@@ -38,7 +39,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * If the lookup locator discovery utility functions as specified, then the
  * listener will receive no events until the <code>setLocators</code> method
  * is called to re-configure the lookup locator discovery utility to discover
  * the lookup services started during setup.
  */
 public class DiscoveryBeginsOnSetLocsAfterNull
                                     extends DiscoveryBeginsOnAddLocsAfterNull
@@ -47,10 +48,11 @@ public class DiscoveryBeginsOnSetLocsAft
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         addLocs = false;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class DiscoveryBeginsOnSetLocsAfterNull
 
@@ -28,7 +29,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *    <li> one or more initial lookup services started during setup
+ *    <li> one or more initial lookup services started during construct
  *    <li> an instance of the lookup locator discovery utility created by
  *         passing null to the constructor
@@ -38,7 +39,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * listener will receive no events until the <code>setLocators</code> method
  * is called to re-configure the lookup locator discovery utility to discover
- * the lookup services started during setup.
+ * the lookup services started during construct.
  */
 public class DiscoveryBeginsOnSetLocsAfterNull

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryEndsOnTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/DiscoveryEndsOnTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/RemoveLocatorsSome.java Wed Jan  2 05:20:52 2013
@@ -19,12 +19,13 @@
 package com.sun.jini.test.spec.locatordiscovery;
 
 import java.util.logging.Level;
-
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 import net.jini.core.discovery.LookupLocator;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * With respect to the <code>removeLocators</code> method, this class
@@ -51,19 +52,20 @@ import java.util.ArrayList;
  */
 public class RemoveLocatorsSome extends Discovered {
 
-    protected ArrayList curLookupsToDiscover = initLookupsToStart;
-    protected ArrayList newLookupsToDiscover = new ArrayList(11);
-    protected ArrayList lookupsToRemoveList = new ArrayList(11);
-    protected LookupLocator[] locsToRemove = new LookupLocator[0];
+    protected volatile List curLookupsToDiscover = new ArrayList(0);
+    protected final List newLookupsToDiscover = new ArrayList(11);
+    protected final List lookupsToRemoveList = new ArrayList(11);
+    protected volatile LookupLocator[] locsToRemove = new LookupLocator[0];
 
-    protected boolean changeAll = false;
+    protected volatile boolean changeAll = false;
 
     /** Performs actions necessary to prepare for execution of the 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        curLookupsToDiscover = getInitLookupsToStart();
         /* Remove the locators for the lookup services at an even index.
          * Remove locators at an odd index as well if changeAll is true.
          */
@@ -71,20 +73,21 @@ public class RemoveLocatorsSome extends 
             LocatorGroupsPair curPair =
                                 (LocatorGroupsPair)curLookupsToDiscover.get(i);
             if( ((i%2) == 0) || changeAll ) {//index is even or changeAll
-                lookupsToRemoveList.add(curPair.locator);
+                lookupsToRemoveList.add(curPair.getLocator());
             } else {
                 newLookupsToDiscover.add(curPair);
             }//endif
         }//end loop
         locsToRemove =(LookupLocator[])(lookupsToRemoveList).toArray
                                (new LookupLocator[lookupsToRemoveList.size()]);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *     <li> re-configures the lookup locator discovery utility to discover
      *          the set of locators whose elements are the locators of each
      *          lookup service that was started during setup
      *     <li> starts the unicast discovery process by adding a discovery
      *          listener to the lookup locator discovery utility
      *     <li> verifies that the discovery process is working by waiting
@@ -71,20 +73,21 @@ public class RemoveLocatorsSome extends 
      *     <li> re-configures the lookup locator discovery utility to discover
      *          the set of locators whose elements are the locators of each
-     *          lookup service that was started during setup
+     *          lookup service that was started during construct
      *     <li> starts the unicast discovery process by adding a discovery
      *          listener to the lookup locator discovery utility

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsDups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsDups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsDups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsDups.java Wed Jan  2 05:20:52 2013
@@ -19,7 +19,7 @@
 package com.sun.jini.test.spec.locatordiscovery;
 
 import java.util.logging.Level;
-
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.LocatorsUtil;
@@ -40,7 +40,7 @@ import java.util.ArrayList;
  *
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more "initial" lookup services, each started during setup,
  *        before the test begins execution
  *   <li> one or more "additional" lookup services, each started after the
  *        test has begun execution
@@ -66,31 +66,32 @@ public class SetLocatorsDups extends Abs
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         /* Create a set of locators to discover that contain duplicates */
         ArrayList newLookups = new ArrayList(11);
-        int len1 = addLookupsToStart.size();
+        int len1 = getAddLookupsToStart().size();
         int len2 = 2*len1;
         for(int i=0;i<len1;i++) {
             LocatorGroupsPair pair
-                                = (LocatorGroupsPair)addLookupsToStart.get(i);
+                                = (LocatorGroupsPair)getAddLookupsToStart().get(i);
             newLookups.add(i,pair);
         }//end loop
         for(int i=len1;i<len2;i++) {
             LocatorGroupsPair pair
-                          = (LocatorGroupsPair)addLookupsToStart.get(i-len1);
+                          = (LocatorGroupsPair)getAddLookupsToStart().get(i-len1);
             newLookups.add(i,pair);
         }//end loop
         dupLocs = toLocatorArray(newLookups);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *     <li> start the additional lookup services
      *     <li> verifies that the lookup locator discovery utility under test
      *          discovers the initial lookup services that were started 
-     *          during setup
+     *          during construct
      *     <li> re-configures the listener's expected event state to expect
      *          the discovery of the new, replacement set of lookup services
      *     <li> re-configures the lookup locator discovery utility to discover
@@ -106,12 +107,12 @@ public class SetLocatorsDups extends Abs
         /* Start the additional lookup services */
         startAddLookups();
         /* Verify discovery of the initial lookups */
-        doDiscovery(initLookupsToStart,mainListener);
+        doDiscovery(getInitLookupsToStart(),mainListener);
         /* Configure the listener's expected event state for the additional
          * lookup services
          */
         mainListener.clearAllEventInfo();
-        mainListener.setLookupsToDiscover(addLookupsToStart);
+        mainListener.setLookupsToDiscover(getAddLookupsToStart());
         /* Configure the lookup locator discovery utility to discover the
          * additional lookups
          */
@@ -40,7 +40,7 @@ import java.util.ArrayList;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more "initial" lookup services, each started during setup,
+ *   <li> one or more "initial" lookup services, each started during construct,
  *        before the test begins execution
  *   <li> one or more "additional" lookup services, each started after the

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsReplaceSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/locatordiscovery/SetLocatorsReplaceSome.java Wed Jan  2 05:20:52 2013
@@ -19,13 +19,14 @@
 package com.sun.jini.test.spec.locatordiscovery;
 
 import java.util.logging.Level;
-
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
 import net.jini.core.discovery.LookupLocator;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * With respect to the <code>setLocators</code> method, this class verifies
@@ -57,28 +58,30 @@ import java.util.ArrayList;
  *
  */
 public class SetLocatorsReplaceSome extends Discovered {
-
-    protected LookupLocator[] newLocatorsToDiscover = new LookupLocator[0];
-    protected ArrayList oldLookupsToDiscover = initLookupsToStart;
-    protected ArrayList newLookupsToDiscover = new ArrayList(11);
-    protected ArrayList newLocatorsList = new ArrayList(11);
-
-    protected boolean changeAll = false;
+    
+    protected final List newLookupsToDiscover = new ArrayList(11);
+    protected final List newLocatorsList = new ArrayList(11);
+
+    protected volatile LookupLocator[] newLocatorsToDiscover = new LookupLocator[0];
+    protected volatile List oldLookupsToDiscover = new ArrayList(0);
+    
+    protected volatile boolean changeAll = false;
 
     /** Performs actions necessary to prepare for execution of the 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        oldLookupsToDiscover = getInitLookupsToStart();
         /* Change the locators for the lookup services at an even index.
          * Change locators at an odd index as well if changeAll is true.
          */
         for(int i=0;i<oldLookupsToDiscover.size();i++) {
             LocatorGroupsPair oldPair =
                                 (LocatorGroupsPair)oldLookupsToDiscover.get(i);
-            LookupLocator oldLoc = oldPair.locator;
-            String[] oldGroups   = oldPair.groups;
+            LookupLocator oldLoc = oldPair.getLocator();
+            String[] oldGroups   = oldPair.getGroups();
             String oldHost       = oldLoc.getHost();
             int    oldPort       = oldLoc.getPort();
             String newHost       = new String(oldHost);
@@ -95,13 +98,14 @@ public class SetLocatorsReplaceSome exte
         }//end loop
         newLocatorsToDiscover =(LookupLocator[])(newLocatorsList).toArray
                                    (new LookupLocator[newLocatorsList.size()]);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *     <li> re-configures the lookup locator discovery utility to discover
      *          the set of locators whose elements are the locators of each
      *          lookup service that was started during setup
      *     <li> starts the unicast discovery process by adding a discovery
      *          listener to the lookup locator discovery utility
      *     <li> verifies that the discovery process is working by waiting
@@ -95,13 +98,14 @@ public class SetLocatorsReplaceSome exte
      *     <li> re-configures the lookup locator discovery utility to discover
      *          the set of locators whose elements are the locators of each
-     *          lookup service that was started during setup
+     *          lookup service that was started during construct
      *     <li> starts the unicast discovery process by adding a discovery
      *          listener to the lookup locator discovery utility

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AbstractBaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AbstractBaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AbstractBaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AbstractBaseTest.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -35,6 +36,8 @@ import net.jini.core.lookup.ServiceRegis
 import java.io.IOException;
 import java.rmi.RemoteException;
 import java.util.ArrayList;
+import java.util.List;
+import java.util.concurrent.CopyOnWriteArrayList;
 
 /**
  * This class is an abstract class that acts as the base class which
@@ -46,7 +49,7 @@ import java.util.ArrayList;
  * multicast request, and unicast request protocols on behalf of the
  * tests that sub-class this abstract class.
  * <p>
  * This class provides an implementation of the <code>setup</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
  *
@@ -56,9 +59,9 @@ import java.util.ArrayList;
  */
 abstract public class AbstractBaseTest extends BaseQATest {
 
-    protected LookupDiscovery lookupDiscovery = null;
-    protected ArrayList lookupDiscoveryList = new ArrayList(1);
-    protected LookupListener mainListener = null;
+    protected volatile LookupDiscovery lookupDiscovery = null;
+    protected final List<LookupDiscovery> lookupDiscoveryList = new CopyOnWriteArrayList<LookupDiscovery>();
+    protected volatile LookupListener mainListener = null;
 
     /** Performs actions necessary to prepare for execution of the 
      *  current test as follows:
@@ -71,8 +74,8 @@ abstract public class AbstractBaseTest e
      *         utility
      * </ul>
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
 	/* Start group discovery by creating a lookup discovery  utility */
 	logger.log(Level.FINE,
 		   "creating a lookup discovery initially "
@@ -83,6 +86,7 @@ abstract public class AbstractBaseTest e
 	     sysConfig.getConfiguration());
 	lookupDiscoveryList.add(lookupDiscovery);
 	mainListener = new LookupListener();
+        return this;
     }
 
     /** Executes the current test
@@ -131,7 +135,7 @@ abstract public class AbstractBaseTest e
      *  </ul>
      *  @throws com.sun.jini.qa.harness.TestException
      */
-    protected void doDiscovery(ArrayList locGroupsListStartedLookups,
+    protected void doDiscovery(List locGroupsListStartedLookups,
                                LookupDiscovery ld,
                                LookupListener listener,
                                String[] groupsToDiscover)
@@ -165,13 +169,13 @@ abstract public class AbstractBaseTest e
 
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when the standard lookup discovery utility
      *  created during setup is to be used for discovery, but the set of
      *  groups to discover is different than the member groups of the
      *  lookup services referenced in the locGroupsListStartedLookups
      *  parameter.
      *  @throws com.sun.jini.qa.harness.TestException
      */
-    protected void doDiscovery(ArrayList locGroupsListStartedLookups,
+    protected void doDiscovery(List locGroupsListStartedLookups,
                                LookupListener listener,
                                String[] groupsToDiscover)
                                                        throws TestException,
@@ -183,13 +187,13 @@ abstract public class AbstractBaseTest e
 
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when a lookup discovery utility different from
      *  the standard one created during setup is to be used for discovery,
      *  and the set of groups to discover is the same as the member groups
      *  of the lookup services referenced in the locGroupsListStartedLookups
      *  parameter.
      *  @throws com.sun.jini.qa.harness.TestException
      */
-    protected void doDiscovery(ArrayList locGroupsListStartedLookups,
+    protected void doDiscovery(List locGroupsListStartedLookups,
                                LookupDiscovery ld,
                                LookupListener listener) throws TestException,
                                                                IOException
@@ -201,13 +205,13 @@ abstract public class AbstractBaseTest e
 
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when the standard lookup discovery utility
      *  created during setup is to be used for discovery, and the set
      *  of groups to discover is the same as the member groups of the
      *  lookup services referenced in the locGroupsListStartedLookups
      *  parameter.
      *  @throws com.sun.jini.qa.harness.TestException
      */
-    protected void doDiscovery(ArrayList locGroupsListStartedLookups,
+    protected void doDiscovery(List locGroupsListStartedLookups,
                                LookupListener listener) throws TestException,
                                                                IOException
     {
@@ -46,7 +49,7 @@ import java.util.ArrayList;
  * tests that sub-class this abstract class.
  * <p>
- * This class provides an implementation of the <code>setup</code> method
+ * This class provides an implementation of the <code>construct</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
@@ -165,13 +169,13 @@ abstract public class AbstractBaseTest e
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when the standard lookup discovery utility
-     *  created during setup is to be used for discovery, but the set of
+     *  created during construct is to be used for discovery, but the set of
      *  groups to discover is different than the member groups of the
      *  lookup services referenced in the locGroupsListStartedLookups
@@ -183,13 +187,13 @@ abstract public class AbstractBaseTest e
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when a lookup discovery utility different from
-     *  the standard one created during setup is to be used for discovery,
+     *  the standard one created during construct is to be used for discovery,
      *  and the set of groups to discover is the same as the member groups
      *  of the lookup services referenced in the locGroupsListStartedLookups
@@ -201,13 +205,13 @@ abstract public class AbstractBaseTest e
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when the standard lookup discovery utility
-     *  created during setup is to be used for discovery, and the set
+     *  created during construct is to be used for discovery, and the set
      *  of groups to discover is the same as the member groups of the
      *  lookup services referenced in the locGroupsListStartedLookups

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -37,7 +38,7 @@ import com.sun.jini.test.share.GroupsUti
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more "initial" lookup services, each belonging to a finite
  *         set of member groups, and each started during setup, before the
  *         test begins execution
  *    <li> one or more "additional" lookup services, each belonging to a finite
  *         set of member groups that does not include any of the member groups
@@ -57,23 +58,24 @@ import com.sun.jini.test.share.GroupsUti
  */
 public class AddGroups extends Discovered {
 
-    protected String[] groupsToAdd = toGroupsArray(addLookupsToStart);
+    protected String[] groupsToAdd = new String[0];
 
     /** Performs actions necessary to prepare for execution of the 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	startAddLookups();//Start the additional lookup services
-	groupsToAdd = toGroupsArray(addLookupsToStart);
-    }//end setup
+	groupsToAdd = toGroupsArray(getAddLookupsToStart());
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> verifies that the lookup discovery utility under test
      *         discovers the initial lookup services that were started 
-     *         during setup
+     *         during construct
      *    <li> re-configures the listener's expected event state to expect
      *         the discovery of the addtional lookup services
      *    <li> invokes addGroups to re-configure the lookup discovery utility
@@ -86,12 +88,12 @@ public class AddGroups extends Discovere
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");
         /* Verify discovery of the initial lookups */
-        doDiscovery(initLookupsToStart,listenerToUse);
+        doDiscovery(getInitLookupsToStart(),listenerToUse);
         /* Configure the listener's expected event state for the additional
          * lookup services
          */
         listenerToUse.clearAllEventInfo();
-        listenerToUse.setLookupsToDiscover(addLookupsToStart);
+        listenerToUse.setLookupsToDiscover(getAddLookupsToStart());
         /* Re-configure the lookup discovery utility to discover the
          * additional lookups
          */
@@ -37,7 +38,7 @@ import com.sun.jini.test.share.GroupsUti
  * <p><ul>
  *    <li> one or more "initial" lookup services, each belonging to a finite
- *         set of member groups, and each started during setup, before the
+ *         set of member groups, and each started during construct, before the
  *         test begins execution
  *    <li> one or more "additional" lookup services, each belonging to a finite

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsAllGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsAllGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsDups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsDups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -36,7 +37,7 @@ import java.util.ArrayList;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more "initial" lookup services, each belonging to a finite
  *         set of member groups, and each started during setup, before the
  *         test begins execution
  *    <li> one or more "additional" lookup services, each belonging to a finite
  *         set of member groups that does not include any of the member groups
@@ -61,8 +62,8 @@ public class AddGroupsDups extends AddGr
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	int len1 = groupsToAdd.length;
 	int len2 = 2*len1;
 	ArrayList dupGroupsList = new ArrayList(len2);
@@ -74,7 +75,8 @@ public class AddGroupsDups extends AddGr
 	}//end loop
 	groupsToAdd = 
 	   (String[])(dupGroupsList).toArray(new String[dupGroupsList.size()]);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class AddGroupsDups
 
@@ -36,7 +37,7 @@ import java.util.ArrayList;
  * <p><ul>
  *    <li> one or more "initial" lookup services, each belonging to a finite
- *         set of member groups, and each started during setup, before the
+ *         set of member groups, and each started during construct, before the
  *         test begins execution
  *    <li> one or more "additional" lookup services, each belonging to a finite

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsNullElement.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/AddGroupsNullElement.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorDups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorDups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -40,7 +41,7 @@ import java.util.ArrayList;
  *
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more initial lookup services started during setup
  *   <li> an instance of the lookup discovery utility constructed
  *        using a set of groups in which at least 1 element duplicates
  *        at least 1 other element in the set
@@ -62,23 +63,24 @@ public class ConstructorDups extends Abs
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	/* Create a set of groups to discover that contain duplicates */
-	int len1 = allLookupsToStart.size();
+	int len1 = getAllLookupsToStart().size();
 	int len2 = 2*len1;
 	for(int i=0;i<len1;i++) {
 	    LocatorGroupsPair pair
-		= (LocatorGroupsPair)allLookupsToStart.get(i);
+		= (LocatorGroupsPair)getAllLookupsToStart().get(i);
 	    newLookups.add(i,pair);
 	}//end loop
 	for(int i=len1;i<len2;i++) {
 	    LocatorGroupsPair pair
-		= (LocatorGroupsPair)allLookupsToStart.get(i-len1);
+		= (LocatorGroupsPair)getAllLookupsToStart().get(i-len1);
 	    newLookups.add(i,pair);
 	}//end loop
 	dupGroups = toGroupsArray(newLookups);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -40,7 +41,7 @@ import java.util.ArrayList;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
- *   <li> one or more initial lookup services started during setup
+ *   <li> one or more initial lookup services started during construct
  *   <li> an instance of the lookup discovery utility constructed
  *        using a set of groups in which at least 1 element duplicates

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorNullElement.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/ConstructorNullElement.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================